pub enum MultiStrategy {
Sum,
WeightedSum {
weights: Vec<Float>,
},
}Expand description
An mupltiple objective strategy type specifies how competitive objective functions are compared among each other.
Variants
Sum
A sum type simply sums all objective values together.
WeightedSum
A weighted sum type uses linear combination of weights and the corresponding fitness values.