pub enum RelationType {
Any,
Sequence,
Strict,
}Expand description
Relation type.
Variants
Any
Relation type which locks jobs to specific vehicle in any order.
Sequence
Relation type which locks jobs in specific order allowing insertion of other jobs in between.
Strict
Relation type which locks jobs in strict order, no insertions in between are allowed.