pub struct VehicleReload {
pub location: Location,
pub duration: Float,
pub times: Option<Vec<Vec<String>>>,
pub tag: Option<String>,
pub resource_id: Option<String>,
}Expand description
Specifies a place where vehicle can load or unload cargo.
Fields
location: LocationA place location.
duration: FloatA total loading/reloading duration (service time).
times: Option<Vec<Vec<String>>>A list of time windows with time specified in RFC3339 format.
tag: Option<String>A tag which will be propagated back within corresponding activity in solution.
resource_id: Option<String>A shared reload resource id.