pub struct PointStop {
pub location: Location,
pub time: Schedule,
pub distance: i64,
pub load: Vec<i32>,
pub parking: Option<Interval>,
pub activities: Vec<Activity>,
}Expand description
A point stop is a stop where vehicle is supposed to be parked and do some work.
Fields
location: LocationStop location. When omitted vehicle can stop anywhere.
time: ScheduleStop schedule.
distance: i64Distance traveled since departure from start.
load: Vec<i32>Vehicle load after departure from this stop.
parking: Option<Interval>Parking time.
activities: Vec<Activity>Activities performed at the stop.