pub enum Objective {
Show 16 variants
MinimizeCost,
MinimizeDistance,
MinimizeDuration,
MinimizeTours,
MaximizeTours,
MaximizeValue {
breaks: Option<Float>,
},
MinimizeUnassigned {
breaks: Option<Float>,
},
MinimizeArrivalTime,
BalanceMaxLoad,
BalanceActivities,
BalanceDistance,
BalanceDuration,
CompactTour {
job_radius: usize,
},
TourOrder,
FastService,
MultiObjective {
strategy: MultiStrategy,
objectives: Vec<Objective>,
},
}Expand description
Specifies objective function types.
Variants
MinimizeCost
An objective to minimize total cost as a linear combination of total time and distance.
MinimizeDistance
An objective to minimize total distance.
MinimizeDuration
An objective to minimize total duration.
MinimizeTours
An objective to minimize total tour amount.
MaximizeTours
An objective to maximize total tour amount.
MaximizeValue
An objective to maximize value of served jobs.
MinimizeUnassigned
An objective to minimize number of unassigned jobs.
Fields
MinimizeArrivalTime
An objective to minimize sum of arrival times from all routes.
BalanceMaxLoad
An objective to balance max load across all tours.
BalanceActivities
An objective to balance activities across all tours.
BalanceDistance
An objective to balance distance across all tours.
BalanceDuration
An objective to balance duration across all tours.
CompactTour
An objective to control how tours are built.
TourOrder
An objective to control order of job activities in the tour.
FastService
An objective to prefer jobs to be served as soon as possible.
MultiObjective
A multi objective allows to define multiple competitive objectives at the same layer of hierarchy.
Fields
strategy: MultiStrategyAn objective composition type.